API docs for “spamfighter.core.counters.Counter”

# Class s.c.c.Counter(object):

Part of spamfighter.core.counters View Source View In Hierarchy

Known subclasses: spamfighter.core.counters.AverageCounter, spamfighter.core.counters.RequestCounter, spamfighter.core.counters.SpeedCounter, spamfighter.core.test.test_counters.TestCounter

Набор одиночных счетчиков, вместе рассчитывающих одно значение для нескольких периодов.

Instance Variables | counter | набор одиночных счетчиков (type: `list(``IAtomCounter``)` )

Method | increment | Увеличить значение счетчика на указанное значение.
Method | __str__ | Представить текущее состояние счетчика в понятном человеку виде.
Method | format | Строка формата для вывода значения счетчика.
Method | values | Получить значения счетчиков в виде массива значений.

def increment(self, value=1): (source)
Увеличить значение счетчика на указанное значение.

Parameters | value | значение инкремента

def __str__(self): (source)
Представить текущее состояние счетчика в понятном человеку виде.

Returns | (type: `str` )

def format(self): (source)
overridden in spamfighter.core.counters.AverageServiceTimeCounter, spamfighter.core.counters.RequestCounter, spamfighter.core.counters.RequestPerSecondCounter, spamfighter.core.test.test_counters.TestCounter
Строка формата для вывода значения счетчика.

def values(self): (source)
overridden in spamfighter.core.counters.AverageCounter, spamfighter.core.counters.SpeedCounter
Получить значения счетчиков в виде массива значений.